==> apache-servicecomb-java-chassis-distribution-1.3.11-src.zip: apache-servicecomb-java-chassis-distribution-1.3.11-src/foundations/foundation-ssl/src/main/java/org/apache/servicecomb/foundation/ssl/SSLOptionFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.foundation.ssl;

import com.netflix.config.ConcurrentCompositeConfiguration;

public interface SSLOptionFactory {
  static SSLOptionFactory createSSLOptionFactory(String tag, ConcurrentCompositeConfiguration configSource) {
    String name = SSLOption.getStringProperty(configSource,
        null,
        "ssl." + tag + ".sslOptionFactory",
        "ssl.sslOptionFactory");
    return createSSLOptionFactory(name);
  }

  static SSLOptionFactory createSSLOptionFactory(String className) {
    if (className != null && !className.isEmpty()) {
      try {
        return (SSLOptionFactory) Class.forName(className).newInstance();
      } catch (InstantiationException | IllegalAccessException | ClassNotFoundException e) {
        throw new IllegalStateException("Failed to create SSLOptionFactory.", e);
      }
    }
    return null;
  }

  SSLOption createSSLOption();
}

==> apache-servicecomb-java-chassis-distribution-2.9.2-src.zip: apache-servicecomb-java-chassis-distribution-2.9.2-src/foundations/foundation-ssl/src/main/java/org/apache/servicecomb/foundation/ssl/SSLOptionFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.foundation.ssl;

import com.netflix.config.ConcurrentCompositeConfiguration;

public interface SSLOptionFactory {
  static SSLOptionFactory createSSLOptionFactory(String tag, ConcurrentCompositeConfiguration configSource) {
    String name = SSLOption.getStringProperty(configSource,
        null,
        "ssl." + tag + ".sslOptionFactory",
        "ssl.sslOptionFactory");
    return createSSLOptionFactory(name);
  }

  static SSLOptionFactory createSSLOptionFactory(String className) {
    if (className != null && !className.isEmpty()) {
      try {
        return (SSLOptionFactory) Class.forName(className).getDeclaredConstructor().newInstance();
      } catch (ReflectiveOperationException e) {
        throw new IllegalStateException("Failed to create SSLOptionFactory.", e);
      }
    }
    return null;
  }

  SSLOption createSSLOption();
}
